<!--
	flex.xslt
	Author: Jan Erik Paulsen
	Copyright 2007 Teppefall
-->
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:mx="http://www.adobe.com/2006/mxml"
	version="1.0"
	>
	<xsl:strip-space elements="*"/>
	<xsl:output encoding="utf-8" method="xml" media-type="text/xml" indent="yes"/>
	<xsl:output cdata-section-elements="string style script"/>
	<xsl:param name="application">FMX 0.1</xsl:param>

	<xsl:template match="/">
		<xsl:comment> Flex to JFC - Copyright 2007 Teppefall (<xsl:value-of select="$application"/>) </xsl:comment>
		<xsl:apply-templates/>
	</xsl:template>
	<!--
		Dette kan vaere en inkluderende fil eller en ActionScript model i .as.
	 -->
	<xsl:template match="*">
		<runtime classId="{name()}">
<!--			<attribute name="default" value="default"/>-->
			<xsl:apply-templates/>
		</runtime>
	</xsl:template>

	<!-- APOLLO -->
	<xsl:template match="mx:ApolloApplication">
		<component>
			<xsl:apply-templates/>
		</component>
	</xsl:template>

	<xsl:template match="mx:HTML">
		<component class="com.teppefall.massive.MassivePanel">
			<property name="home" value=" {@location}"/>
		</component>
	</xsl:template>

	<!-- FLEX UI -->
	<xsl:template match="mx:Application">
		<component>
			<xsl:apply-templates/>
		</component>
	</xsl:template>

	<xsl:template match="mx:Script">
		<script>
		</script>
	</xsl:template>

	<xsl:template match="mx:Style">
		<style>
			<xsl:value-of select="."/>
		</style>
	</xsl:template>

	<!-- GUI -->
	<xsl:template match="mx:TabNavigator |
						 mx:Label |
						 mx:Text |
						 mx:TextArea |
						 mx:TextInput |
						 mx:CheckBox |
						 mx:ComboBox |
						 mx:Button |
						 mx:LinkButton |
						 mx:Repeater |
						 mx:Tile |
						 mx:ControlBar |
						 mx:Image"
						 >
		<xsl:param name="tagName">
			<xsl:value-of select="substring(name(), 4)"/>
		</xsl:param>
		<!--<xsl:value-of select="$tagName"/>-->
		<xsl:param name="className">
	        <xsl:choose>
	            <xsl:when test="$tagName = 'TabNavigator'">javax.swing.JTabbedPane</xsl:when>
<!--	            <xsl:when test="$tagName = 'Panel'">javax.swing.JPanel</xsl:when>-->
	            <xsl:when test="$tagName = 'ControlBar'">javax.swing.JPanel</xsl:when>
	            <xsl:when test="$tagName = 'Repeater'">javax.swing.JPanel</xsl:when>
	            <xsl:when test="$tagName = 'Tile'">javax.swing.JPanel</xsl:when>
	            <xsl:when test="$tagName = 'Label'">javax.swing.JLabel</xsl:when>
	            <xsl:when test="$tagName = 'Text'">javax.swing.JLabel</xsl:when>
	            <xsl:when test="$tagName = 'TextArea'">javax.swing.JScrollPane</xsl:when>
	            <xsl:when test="$tagName = 'TextInput'">javax.swing.JTextField</xsl:when>
	            <xsl:when test="$tagName = 'CheckBox'">javax.swing.JCheckBox</xsl:when>
	            <xsl:when test="$tagName = 'ComboBox'">javax.swing.JComboBox</xsl:when>
	            <xsl:when test="$tagName = 'Button'">javax.swing.JButton</xsl:when>
	            <xsl:when test="$tagName = 'LinkButton'">javax.swing.JButton</xsl:when>
	            <xsl:when test="$tagName = 'Image'">javax.swing.JLabel</xsl:when>
	            <xsl:otherwise>UNKNOWN - <xsl:value-of select="name()"/></xsl:otherwise>
	        </xsl:choose>
		</xsl:param>
		<component class="{$className}">
			<xsl:if test="@text">
				<property name="text" value="{@text}"/>
			</xsl:if>
			<xsl:if test="@label">
				<property name="text" value="{@label}"/>
			</xsl:if>
			
			<xsl:if test="@dataProvider">
				<xsl:comment>
					<xsl:value-of select="@dataProvider"/>
				</xsl:comment>
			</xsl:if>
			
			<xsl:if test="$tagName = 'TextArea'">
				<property name="viewportView" type="Component">
					<component class="javax.swing.JTextArea"/>
				</property>
			</xsl:if>

			<xsl:if test="$tagName = 'Tile'">
				<property name="background" type="color" value="#ff0000"/>
			</xsl:if>


			<xsl:apply-templates/>
		</component>
	</xsl:template>

	<!-- LAYOUT -->
	<xsl:template match="mx:VBox | mx:HBox | mx:Panel">
		<xsl:param name="tagName">
			<xsl:value-of select="substring(name(), 4)"/>
		</xsl:param>
		<xsl:param name="className">
	        <xsl:choose>
	            <xsl:when test="$tagName = 'HBox'">com.teppefall.ds.layout.jxml.AssemblyBoxLayout$HBox</xsl:when>
	            <xsl:otherwise>com.teppefall.ds.layout.jxml.AssemblyBoxLayout$VBox</xsl:otherwise>
	        </xsl:choose>
		</xsl:param>
		<!--
		<component class="javax.swing.JScrollPane">
		    <property name="viewportView" type="Component">
			</property>
		</component>
		-->
				<layout class="{$className}" link="true">
					<xsl:if test="$tagName = 'Panel' and name(parent::*) = 'mx:TabNavigator'">
						<xsl:attribute name="constraint">
							<xsl:value-of select="@label"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates/>
				</layout>
	</xsl:template>

	<!-- EFFECTS -->
	<xsl:template match="mx:Fade">
		<effect class="{name()}">
			<xsl:apply-templates/>
		</effect>
	</xsl:template>

	<!-- HTTP -->
	<xsl:template match="mx:HTTPService">
		<service>
			<xsl:apply-templates/>
		</service>
	</xsl:template>

	<!-- DATA -->
	<xsl:template match="mx:Array">
		<vector>
			<xsl:if test="@id">
				<xsl:attribute name="id">
					<xsl:value-of select="@id"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates/>
		</vector>
	</xsl:template>

	<xsl:template match="mx:String">
		<item>
			<xsl:apply-templates/>
		</item>
	</xsl:template>



</xsl:stylesheet>
	
	